// Code modified form the following by Hans Huth

/*************************************************** 
  This is an example for the AM2315 Humidity + Temp sensor

  Designed specifically to work with the Adafruit BMP085 Breakout 
  ----> https://www.adafruit.com/products/1293

  These displays use I2C to communicate, 2 pins are required to  
  interface
  Adafruit invests time and resources providing this open source code, 
  please support Adafruit and open-source hardware by purchasing 
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.  
  BSD license, all text above must be included in any redistribution
 ****************************************************/

// AND

/* ReadSHT1xValues
 *
 * Read temperature and humidity values from an SHT1x-series (SHT10,
 * SHT11, SHT15) sensor.
 *
 * Copyright 2009 Jonathan Oxer <jon@oxer.com.au>
 * www.practicalarduino.com
 * 
 */

// I am testing this this:
// https://learn.adafruit.com/adafruit-feather-huzzah-esp8266 
// https://learn.adafruit.com/adafruit-feather-huzzah-esp8266/pinouts

// Battery voltage monitoring:
// https://learn.adafruit.com/using-ifttt-with-adafruit-io/wiring

#include "config.h"

// AM2315 - I2C
#include <Wire.h>
#include <Adafruit_AM2315.h>

// Connect RED of the AM2315 sensor to 5.0V
// Connect BLACK to Ground

// Connect WHITE to i2c clock - on Huzzah, SCL (pin 4)
// Connect YELLOW to i2c data - on Huzzah, SDA (pin 5)

Adafruit_AM2315 am2315;

// SHT10 - SPI

#include <SHT1x.h>

// Specify data and clock connections and instantiate SHT1x object
#define shallow 12 
//pin 15 didn't work - this from Adafruit:
// GPIO #15, is also used to detect boot-mode. It has a pulldown resistor 
// connected to it, make sure this pin isn't pulled high on startup. 


#define deep 16
#define clockPin 14

#define ADC A0

SHT1x sht10_shallow(shallow, clockPin);
SHT1x sht10_deep(deep, clockPin);

// now for the Adafruit IO feeds

  int countM = 0;

  AdafruitIO_Feed *counterM = io.feed("counterM");

  AdafruitIO_Feed *airTempF = io.feed("airTempF");
  AdafruitIO_Feed *airHumid = io.feed("airHumid");

  AdafruitIO_Feed *shallowTempF = io.feed("shallowTempF");
  AdafruitIO_Feed *shallowHumid = io.feed("shallowHumid");

  AdafruitIO_Feed *deepTempF = io.feed("deepTempF");
  AdafruitIO_Feed *deepHumid = io.feed("deepHumid");

  AdafruitIO_Feed *vBattery = io.feed("vBattery");


void setup() {
  
  Serial.begin(9600);

  // wait for serial monitor to open
  while(! Serial);

  Serial.print("Connecting to Adafruit IO");

  // connect to io.adafruit.com
  io.connect();

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

  pinMode(ADC, INPUT);  

  Serial.println("AM2315 Test!");

  if (! am2315.begin()) {
     Serial.println("Sensor not found, check wiring & pullups!");
     while (1);
  }

}

void loop() {

  float vbat = analogRead(ADC) * 0.006; 


  // io.run() should always be present at the top of your loop
  //    a) keeps the client connected to io.adafruit.com
  //    b) processes any incoming data.
  io.run();
  
  // Adafruit IO is rate limited for publishing; wait three seconds
  delay(3000);

  // Record battery voltage
  Serial.print("Battery voltage: ");
  Serial.println(vbat);

  Serial.print("sending -> ");
  Serial.println(vbat);
  vBattery->save(vbat); //counter is feed; count is variable with data
  

  // Record count post

  Serial.print("sending -> ");
  Serial.println(countM);
  counterM->save(countM); //counter is feed; count is variable with data
  // increment the count by 1
  countM++;

  // AM2315 air temp post

  float airC = am2315.readTemperature();
  float airF = (airC*1.8) + 32;
  Serial.print("sending -> ");
  Serial.println(airF);
  airTempF->save(airF);
  delay(3000); 

  // AM2315 humidity post

  float airH= am2315.readHumidity();
  Serial.print("sending -> ");
  Serial.println(airH);
  airHumid->save(airH); 
   
  // shallow temp and humidity post

  float shalC = sht10_shallow.readTemperatureC();
  float shalF= sht10_shallow.readTemperatureF();
  float shalH = sht10_shallow.readHumidity();

  Serial.print("sending -> ");
  Serial.println(shalF);
  shallowTempF->save(shalF); 

  Serial.print("sending -> ");
  Serial.println(shalH);
  shallowHumid->save(shalH); 

  // deep temp and humidity post
  
  float deepC = sht10_deep.readTemperatureC();
  float deepF = sht10_deep.readTemperatureF();
  float deepH = sht10_deep.readHumidity();

  Serial.print("sending -> ");
  Serial.println(deepF);
  deepTempF->save(deepF);

  Serial.print("sending -> ");
  Serial.println(deepH);
  deepHumid->save(deepH);

  delay(30000); // Delay 30 second to be within constraint* of free account:
               // *30 data points per minute
               // 10 feeds
               //  5 dashboards
               // 15 minute triggers
}
